package CloudHealth::CLI;
  our $VERSION = '0.01';
1;

### main pod documentation begin ###

=encoding UTF-8

=head1 NAME

Azure::CLI - A CLI for the CloudHealth API

=head1 SYNOPSIS

  cloudheath-cli help

=head1 DESCRIPTION

A command line utility to interact with L<CloudHealth::API> from the command line

=head1 AUTHOR

    Jose Luis Martinez
    CPAN ID: JLMARTIN
    CAPSiDE
    jlmartinez@capside.com

=head1 COPYRIGHT and LICENSE

(c) 2018 CAPSiDE S.L.

This code is distributed under the Apache v2 License

=cut
